==> ride-components-react-0.0.12.tgz: package/components/cards/card.tsx <==
import { CssClassList } from '../../utilities/css';
import { card } from '../../css/cards/';
import { colours } from '../../css/colours/';

export interface ICardHeaderProps {
  /**
   * card header color
   * @type {string}
   */
  color?: string;
  /**
   * card header additional css classname
   * @type {string}
   */
  className?: string;
  /**
   * card header background image path
   * @type {string}
   */
  image?: string;
  /**
   * sets the card header as tall.
   *  It is useful when applying large background images or to display cards
   *  in applications like Instagram
   * @type {string}
   */
  tall?: boolean;
}

export interface ICardProps {
  /**
   * you can add a React.Component after the content
   */
  afterContent?: any;
  /**
   * you can add a React.Component before the content
   */
  beforeContent?: any;
  /**
   * card's header colour
   */
  color?: string;
  /**
   * footer content. Pass a React.Component
   */
  footer?: any;
  /**
   * if set to true, the header will not display at all
   */
  hideHeader?: boolean;
  /**
   * You can add some css classes to the header
   * @type {string}
   */
  headerClassName?: string;
  /**
   * Header backgroundImage src
   * @type {string}
   */
  headerImage?: string;
  /**
   * if set to true, the header will be higher than normal
   */
  headerTall?: boolean;
  /**
   * header text
   */
  title?: string;
}

export class CardHeader extends React.Component<ICardHeaderProps, {}> {
  public render() {
    let _css = new CssClassList(card.header.header);
    let _style: React.CSSProperties = {};
    _css.add(card.header[this.props.color || colours.blue]);
    _css.add(this.props.className || '');
    if (this.props.tall) _css.add(card.header.tall);
    if (this.props.image) _style.backgroundImage = this.props.image;
    return (
      <header className={_css.toString()} style={_style}>
        {this.props.children}
      </header>
    )
  }
}

export class Card extends React.Component<ICardProps, {}> {
  public static Header = CardHeader;

  public render() {
    return (
      <article className={card.card}>
        {
          !this.props.hideHeader ?
            <CardHeader color={this.props.color} className={this.props.headerClassName} image={this.props.headerImage}>{this.props.title}</CardHeader>
          : null
        }
        {this.props.beforeContent}
        <div className={card.content}>{this.props.children}</div>
        {this.props.afterContent}
        {
          this.props.footer ?
            <footer className={card.footer}>{this.props.footer}</footer>
          : null
        }
      </article>
    )
  }
}

==> ride-components-react-0.0.16.tgz: package/components/cards/card.tsx <==
import { capitalizeFirst } from '../../utilities/string';
import { CssClassList } from '../../utilities/css';
import * as css from 'ride-components/dist/ts/css/card';

export interface ICardHeaderProps {
  /**
   * card header color
   * @type {string}
   */
  color?: string;
  /**
   * card header additional css classname
   * @type {string}
   */
  className?: string;
  /**
   * card header background image path
   * @type {string}
   */
  image?: string;
  /**
   * sets the card header as tall.
   *  It is useful when applying large background images or to display cards
   *  in applications like Instagram
   * @type {string}
   */
  tall?: boolean;
}

export interface ICardProps {
  /**
   * you can add a React.Component after the content
   */
  afterContent?: any;
  /**
   * you can add a React.Component before the content
   */
  beforeContent?: any;
  /**
   * card's header colour
   */
  color?: string;
  /**
   * footer content. Pass a React.Component
   */
  footer?: any;
  /**
   * if set to true, the header will not display at all
   */
  hideHeader?: boolean;
  /**
   * You can add some css classes to the header
   * @type {string}
   */
  headerClassName?: string;
  /**
   * Header backgroundImage src
   * @type {string}
   */
  headerImage?: string;
  /**
   * if set to true, the header will be higher than normal
   */
  headerTall?: boolean;
  /**
   * header text
   */
  title?: string;
}

export class CardHeader extends React.Component<ICardHeaderProps, {}> {
  public render() {
    let _css = new CssClassList(css.card__header);
    let _style: React.CSSProperties = {};
    _css.add(
      this.props.color
      ? css.card__header + capitalizeFirst(this.props.color)
      : css.card__headerBlue
    );
    _css.add(this.props.className || '');
    if (this.props.tall) _css.add(css.card__headerTall);
    if (this.props.image) _style.backgroundImage = this.props.image;
    return (
      <header className={_css.toString()} style={_style}>
        {this.props.children}
      </header>
    )
  }
}

export class Card extends React.Component<ICardProps, {}> {
  public static Header = CardHeader;

  public render() {
    return (
      <article className={css.card}>
        {
          !this.props.hideHeader ?
            <CardHeader color={this.props.color} className={this.props.headerClassName} image={this.props.headerImage}>{this.props.title}</CardHeader>
          : null
        }
        {this.props.beforeContent}
        <div className={css.card__content}>{this.props.children}</div>
        {this.props.afterContent}
        {
          this.props.footer ?
            <footer className={css.card__footer}>{this.props.footer}</footer>
          : null
        }
      </article>
    )
  }
}
